==> php83-nextcloud-28.0.2.tgz: share/nextcloud/apps/encryption/l10n/pt_PT.js <==
OC.L10N.register(
    "encryption",
    {
    "Missing recovery key password" : "Palavra-passe da chave de recuperação em falta",
    "Please repeat the recovery key password" : "Por favor, repita a palavra-passe da chave de recuperação",
    "Repeated recovery key password does not match the provided recovery key password" : "A confirmação da palavra-passe da chave de recuperação não corresponde",
    "Recovery key successfully enabled" : "A chave de recuperação foi ativada com sucesso",
    "Could not enable recovery key. Please check your recovery key password!" : "Não foi possível ativar a chave de recuperação. Por favor, verifique a sua palavra-passe da chave de recuperação!",
    "Recovery key successfully disabled" : "A chave de recuperação foi desativada com sucesso",
    "Could not disable recovery key. Please check your recovery key password!" : "Não foi possível desativar a chave de recuperação. Por favor, verifique a palavra-passe da chave de recuperação.",
    "Missing parameters" : "Parâmetros em falta",
    "Please provide the old recovery password" : "Por favor, indique a palavra-passe de recuperação antiga",
    "Please provide a new recovery password" : "Por favor, indique a nova palavra-passe de recuperação",
    "Please repeat the new recovery password" : "Por favor, repita a nova palavra-passe de recuperação",
    "Password successfully changed." : "Palavra-passe alterada com sucesso.",
    "Could not change the password. Maybe the old password was not correct." : "Não foi possível alterar a palavra-passe. Possivelmente a palavra-passe antiga não está correta.",
    "Recovery Key disabled" : "Chave de Recuperação desativada",
    "Recovery Key enabled" : "Chave de Recuperação ativada",
    "Could not enable the recovery key, please try again or contact your administrator" : "Não foi possível ativar a chave de recuperação, por favor, tente de novo ou contacte o seu administrador",
    "Could not update the private key password." : "Não foi possível atualizar a palavra-passe da chave privada.",
    "The old password was not correct, please try again." : "A palavra-passe antiga não estava correta, por favor, tente de novo.",
    "The current log-in password was not correct, please try again." : "A palavra-passe de iniciar a sessão atual não estava correta, por favor, tente de novo.",
    "Private key password successfully updated." : "A palavra-passe da chave privada foi atualizada com sucesso. ",
    "Invalid private key for encryption app. Please update your private key password in your personal settings to recover access to your encrypted files." : "Chave privada inválida para a aplicação de cifra. Por favor actualize a sua chave privada nas definições pessoais para recuperar acesso aos seus ficheiros cifrados.",
    "Encryption App is enabled, but your keys are not initialized. Please log-out and log-in again." : "Aplicação de cifra está activa, mas as suas chaves não estão inicializaras. Por favor, faça logout e autentique-se novamente.",
    "Please enable server side encryption in the admin settings in order to use the encryption module." : "Por favor active cifragem no servidor nas definições de administrador para usar o módulo de cifra.",
    "Encryption app is enabled and ready" : "Aplicação de cifra activa e pronta a usar",
    "Bad Signature" : "Má Assinatura",
    "Missing Signature" : "Assinatura em Falta",
    "one-time password for server-side-encryption" : "palavra-passe de utilização única para a encriptação do lado do servidor",
    "Default encryption module" : "Módulo de cifra padrão",
    "Default encryption module for server-side encryption" : "Módulo de encriptação predefinido para encriptação do lado do servidor",
    "Encryption app is enabled but your keys are not initialized, please log-out and log-in again" : "Aplicação de cifra está activa, mas as suas chaves não estão inicializaras. Por favor, faça logout e autentique-se novamente.",
    "Encrypt the home storage" : "Encriptar o armazenamento do início",
    "Enabling this option encrypts all files stored on the main storage, otherwise only files on external storage will be encrypted" : "Ativando esta opção todos os ficheiros armazenados no armazenamento principal serão encriptados, senão serão encriptados todos os ficheiros no armazenamento externo",
    "Enable recovery key" : "Ativar a chave de recuperação",
    "Disable recovery key" : "Desativar a chave de recuperação",
    "The recovery key is an extra encryption key that is used to encrypt files. It allows recovery of a user's files if the user forgets his or her password." : "A chave de recuperação é uma chave de encriptação extra que é utilizada para encriptar os ficheiros. Esta permite a recuperação dos ficheiros do utilizador se este esquecer a sua senha.",
    "Recovery key password" : "Palavra-passe da chave de recuperação",
    "Repeat recovery key password" : "Repetir a palavra-passe da chave de recuperação",
    "Change recovery key password:" : "Alterar a palavra-passe da chave de recuperação:",
    "Old recovery key password" : "Palavra-passe da chave de recuperação antiga",
    "New recovery key password" : "Nova palavra-passe da chave de recuperação",
    "Repeat new recovery key password" : "Repetir palavra-passe da chave de recuperação",
    "Change Password" : "Alterar Palavra-passe",
    "Basic encryption module" : "Módulo de cifra básica",
    "Your private key password no longer matches your log-in password." : "A palavra-passe da sua chave privada já não coincide com a palavra-passe da sua sessão.",
    "Set your old private key password to your current log-in password:" : "Defina a sua palavra-passe antiga da chave privada para a sua palavra-passe atual da sessão:",
    " If you don't remember your old password you can ask your administrator to recover your files." : "Se não se lembra da palavra-passe antiga pode pedir ao seu administrador para recuperar os seus ficheiros. ",
    "Old log-in password" : "Palavra-passe antiga da sessão",
    "Current log-in password" : "Palavra-passe atual da sessão",
    "Update Private Key Password" : "Atualizar Palavra-passe da Chave Privada ",
    "Enable password recovery:" : "Ativar a recuperação da palavra-passe:",
    "Enabling this option will allow you to reobtain access to your encrypted files in case of password loss" : "Ao ativar esta opção, irá fazer com que volte a obter o acesso aos seus ficheiros encriptados, se perder a palavra-passe",
    "Enabled" : "Ativada",
    "Disabled" : "Desativada",
    "In order to use this encryption module you need to enable server-side\n\t\tencryption in the admin settings. Once enabled this module will encrypt\n\t\tall your files transparently. The encryption is based on AES 256 keys.\n\t\tThe module won't touch existing files, only new files will be encrypted\n\t\tafter server-side encryption was enabled. It is also not possible to\n\t\tdisable the encryption again and switch back to a unencrypted system.\n\t\tPlease read the documentation to know all implications before you decide\n\t\tto enable server-side encryption." : "Para usar este módulo de encriptação, você precisa ativar a encriptação do lado do servidor\n\t\t nas configurações de administrador. Uma vez ativado, este módulo encriptará\n\t\t todos os seus ficheiros de forma transparente. A encriptação é baseada em chaves AES 256.\n\t\t O módulo não tocará nos ficheiros existentes, apenas os novos serão encriptados\n\t\t depois da encriptação do lado do servidor ser ativada. Também não é possível\n\t\t desativar a encriptação novamente e voltar para um sistema não encriptado.\n\t\tPor favor leia a documentação para conhecer todas as implicações antes de decidir\n\t\tativar a encriptação no servidor."
},
"nplurals=3; plural=(n == 0 || n == 1) ? 0 : n != 0 && n % 1000000 == 0 ? 1 : 2;");

==> php83-nextcloud-32.0.1.tgz: share/nextcloud/apps/encryption/l10n/pt_PT.js <==
OC.L10N.register(
    "encryption",
    {
    "Missing recovery key password" : "Palavra-passe da chave de recuperação em falta",
    "Please repeat the recovery key password" : "Por favor, repita a palavra-passe da chave de recuperação",
    "Repeated recovery key password does not match the provided recovery key password" : "A confirmação da palavra-passe da chave de recuperação não corresponde",
    "Recovery key successfully enabled" : "A chave de recuperação foi ativada com sucesso",
    "Could not enable recovery key. Please check your recovery key password!" : "Não foi possível ativar a chave de recuperação. Por favor, verifique a sua palavra-passe da chave de recuperação!",
    "Recovery key successfully disabled" : "A chave de recuperação foi desativada com sucesso",
    "Could not disable recovery key. Please check your recovery key password!" : "Não foi possível desativar a chave de recuperação. Por favor, verifique a palavra-passe da chave de recuperação.",
    "Missing parameters" : "Parâmetros em falta",
    "Please provide the old recovery password" : "Por favor, indique a palavra-passe de recuperação antiga",
    "Please provide a new recovery password" : "Por favor, indique a nova palavra-passe de recuperação",
    "Please repeat the new recovery password" : "Por favor, repita a nova palavra-passe de recuperação",
    "Password successfully changed." : "Palavra-passe alterada com sucesso.",
    "Could not change the password. Maybe the old password was not correct." : "Não foi possível alterar a palavra-passe. Possivelmente a palavra-passe antiga não está correta.",
    "Recovery Key disabled" : "Chave de Recuperação desativada",
    "Recovery Key enabled" : "Chave de Recuperação ativada",
    "Could not enable the recovery key, please try again or contact your administrator" : "Não foi possível ativar a chave de recuperação, por favor, tente de novo ou contacte o seu administrador",
    "Could not update the private key password." : "Não foi possível atualizar a palavra-passe da chave privada.",
    "The old password was not correct, please try again." : "A palavra-passe antiga não estava correta, por favor, tente de novo.",
    "The current log-in password was not correct, please try again." : "A palavra-passe de iniciar a sessão atual não estava correta, por favor, tente de novo.",
    "Private key password successfully updated." : "A palavra-passe da chave privada foi atualizada com sucesso. ",
    "Invalid private key for encryption app. Please update your private key password in your personal settings to recover access to your encrypted files." : "Chave privada inválida para a aplicação de cifra. Por favor atualize a sua chave privada nas definições pessoais para recuperar acesso aos seus ficheiros cifrados.",
    "Encryption App is enabled, but your keys are not initialized. Please log-out and log-in again." : "A aplicação de encriptação está ativada, mas as suas chaves não foram inicializadas. Termine a sessão e inicie sessão novamente.",
    "Please enable server side encryption in the admin settings in order to use the encryption module." : "Para poder utilizar o módulo de encriptação, ative a encriptação do lado do servidor nas definições de administração.",
    "Encryption app is enabled and ready" : "A aplicação de encriptação está ativada e pronta",
    "Bad Signature" : "Má Assinatura",
    "Missing Signature" : "Assinatura em Falta",
    "one-time password for server-side-encryption" : "palavra-passe de utilização única para a encriptação do lado do servidor",
    "Default encryption module" : "Módulo de cifra padrão",
    "Encryption app is enabled but your keys are not initialized, please log-out and log-in again" : "A aplicação de encriptação está ativada mas as suas chaves não foram inicializadas, termine a sessão e inicie sessão novamente",
    "Encrypt the home storage" : "Encriptar o armazenamento do início",
    "Enabling this option encrypts all files stored on the main storage, otherwise only files on external storage will be encrypted" : "Ativando esta opção todos os ficheiros armazenados no armazenamento principal serão encriptados, senão serão encriptados todos os ficheiros no armazenamento externo",
    "Enable recovery key" : "Ativar a chave de recuperação",
    "Disable recovery key" : "Desativar a chave de recuperação",
    "Recovery key password" : "Palavra-passe da chave de recuperação",
    "Repeat recovery key password" : "Repetir a palavra-passe da chave de recuperação",
    "Change recovery key password:" : "Alterar a palavra-passe da chave de recuperação:",
    "Old recovery key password" : "Palavra-passe da chave de recuperação antiga",
    "New recovery key password" : "Nova palavra-passe da chave de recuperação",
    "Repeat new recovery key password" : "Repetir palavra-passe da chave de recuperação",
    "Change Password" : "Alterar Palavra-passe",
    "Basic encryption module" : "Módulo de cifra básica",
    "Your private key password no longer matches your log-in password." : "A palavra-passe da sua chave privada já não coincide com a palavra-passe da sua sessão.",
    "Set your old private key password to your current log-in password:" : "Defina a sua palavra-passe antiga da chave privada para a sua palavra-passe atual da sessão:",
    "Old log-in password" : "Palavra-passe antiga da sessão",
    "Current log-in password" : "Palavra-passe atual da sessão",
    "Update Private Key Password" : "Atualizar Palavra-passe da Chave Privada ",
    "Enable password recovery:" : "Ativar a recuperação da palavra-passe:",
    "Enabling this option will allow you to reobtain access to your encrypted files in case of password loss" : "Ao ativar esta opção, irá fazer com que volte a obter o acesso aos seus ficheiros encriptados, se perder a palavra-passe",
    "Enabled" : "Ativada",
    "Disabled" : "Desativada",
    "Default encryption module for server-side encryption" : "Módulo de encriptação predefinido para encriptação do lado do servidor"
},
"nplurals=3; plural=(n == 0 || n == 1) ? 0 : n != 0 && n % 1000000 == 0 ? 1 : 2;");
